import { Entity, PrimaryGeneratedColumn, Column, Unique } from "typeorm";
import bcrypt from 'bcrypt';

@Entity()
@Unique(['username'])
export class User {
    @PrimaryGeneratedColumn()
    id!: number;

    @Column()
    username!: string

    @Column()
    password!: string

    @Column({nullable: true})
    token!: string

    @Column({nullable: true})
    displayName!: string

    async comparePassword(password: string): Promise<boolean> {
        return await bcrypt.compare(password, this.password);  
    }

    generateToken() {
        this.token = crypto.randomUUID();
    }
}